==> com.liferay.dynamic.data.mapping.form.renderer-4.0.40.jar: META-INF/resources/js/store/actions/handleFieldEdited.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@4.0.40/js/store/actions/handleFieldEdited.es", ['module', 'exports', 'require', '../../util/evaluation.es', '../../util/visitors.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _evaluation = require("../../util/evaluation.es");

  var _visitors = require("../../util/visitors.es");

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  var _default = function _default(evaluatorContext, properties) {
    var fieldInstance = properties.fieldInstance,
        value = properties.value;
    var evaluable = fieldInstance.evaluable,
        fieldName = fieldInstance.fieldName;
    var editingLanguageId = evaluatorContext.editingLanguageId,
        pages = evaluatorContext.pages;
    var pageVisitor = new _visitors.PagesVisitor(pages);
    var editedPages = pageVisitor.mapFields(function (field) {
      if (field.name === fieldInstance.name) {
        field = _objectSpread({}, field, {
          localizedValue: _objectSpread({}, field.localizedValue, _defineProperty({}, editingLanguageId, value)),
          value: value
        });
      } else if (field.nestedFields) {
        field = _objectSpread({}, field, {
          nestedFields: field.nestedFields.map(function (nestedField) {
            if (nestedField.name === fieldInstance.name) {
              nestedField = _objectSpread({}, nestedField, {
                localizedValue: _objectSpread({}, field.localizedValue, _defineProperty({}, editingLanguageId, value)),
                value: value
              });
            }

            return nestedField;
          })
        });
      }

      return field;
    });
    var promise = Promise.resolve(editedPages);

    if (evaluable) {
      promise = (0, _evaluation.evaluate)(fieldName, _objectSpread({}, evaluatorContext, {
        pages: editedPages
      }));
    }

    return promise;
  };

  exports["default"] = _default;
  //# sourceMappingURL=handleFieldEdited.es.js.map
});
//# sourceMappingURL=handleFieldEdited.es.js.map

==> com.liferay.dynamic.data.mapping.form.renderer-4.0.53.jar: META-INF/resources/js/store/actions/handleFieldEdited.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@4.0.53/js/store/actions/handleFieldEdited.es", ['module', 'exports', 'require', '../../util/visitors.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _visitors = require("../../util/visitors.es");

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  var getEditedField = function getEditedField(field, editingLanguageId, name, value) {
    return _objectSpread({}, field, {
      localizedValue: _objectSpread({}, field.localizedValue, _defineProperty({}, editingLanguageId, value)),
      value: value
    });
  };

  var getEditedPages = function getEditedPages(pages, editingLanguageId, name, value) {
    var pageVisitor = new _visitors.PagesVisitor(pages);
    return pageVisitor.mapFields(function (field) {
      if (field.name === name) {
        field = getEditedField(field, editingLanguageId, name, value);
      } else if (field.nestedFields) {
        field = _objectSpread({}, field, {
          nestedFields: field.nestedFields.map(function (nestedField) {
            if (nestedField.name === name) {
              nestedField = getEditedField(nestedField, editingLanguageId, name, value);
            }

            return nestedField;
          })
        });
      }

      return field;
    });
  };

  var _default = function _default(evaluatorContext, properties) {
    var fieldInstance = properties.fieldInstance,
        value = properties.value;
    var editingLanguageId = evaluatorContext.editingLanguageId,
        pages = evaluatorContext.pages;
    return getEditedPages(pages, editingLanguageId, fieldInstance.name, value);
  };

  exports["default"] = _default;
  //# sourceMappingURL=handleFieldEdited.es.js.map
});
//# sourceMappingURL=handleFieldEdited.es.js.map
